﻿using App.VolgaIt.Dto;
using App.VolgaIt.Mappers;
using Domain.VolgaIt.Entities;
using Infrastructure.VolgaIt;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace App.VolgaIt.Services
{
    public class AdService
    {
        private UnitOfWork _uow;

        public AdService(UnitOfWork uow)
        {
            _uow = uow;
        }

        public async Task<List<AdDto>> GetAllAdsAsync()
        {
            var ads = await _uow.AdRepo.GetAllEntitiesAsync();
            return ads.Select(AdMapper.AdMapToAdDto).ToList();
        }

        public async Task<List<AdDto>> GetAdsByCategoryNameAsync(string categoryName)
        {
            var category = await _uow.AdCtgRepo.FindEntityByAsync(x => x.Name == categoryName);
            var ads = await _uow.AdRepo.FindEntitiesByAsync(x => x.Category == category);

            return ads.Select(AdMapper.AdMapToAdDto).ToList();
        }

        public Task EditAdAsync(EditAdDto dto, bool v, object p)
        {
            throw new NotImplementedException();
        }

        public async Task<List<AdDto>> GetAdsBySubCategoryNameAsync(string subCategoryName)
        {
            var subCategory = await _uow.AdSubCtgRepo.FindEntityByAsync(x => x.Name == subCategoryName);
            var ads = await _uow.AdRepo.FindEntitiesByAsync(x => x.SubCategory == subCategory);

            return ads.Select(AdMapper.AdMapToAdDto).ToList();
        }

        public async Task EditAdAsync(EditAdDto dto, bool isUserAs, string userLogin)
        {
            var ad = await FindAdAsync(dto.AdId, isUserAs, userLogin);

            var newCategory = dto.AdCategoryId != null ? await _uow.AdCtgRepo.FindEntityByIdAsync(dto.AdCategoryId) : null;
            var newSubCategory = dto.AdSubCategoryId != null ? await _uow.AdSubCtgRepo.FindEntityByIdAsync(dto.AdSubCategoryId) : null;
            var newAdType =  dto.AdTypeId != null ? await _uow.AdTypeRepo.FindEntityByIdAsync(dto.AdTypeId) : null;

            ad.Name = dto.Name != null ? dto.Name : ad.Name;
            ad.Description = dto.Description != null ? dto.Name : ad.Name;
            ad.Category = newCategory != null ? newCategory : ad.Category;
            ad.SubCategory = newSubCategory != null ? newSubCategory : ad.SubCategory;
            ad.AdType = dto.AdTypeId != null ? newAdType : ad.AdType;

            await _uow.SaveChangesAsync();
        }

        public async Task RemoveAdAsync(string adId, bool isUserAs, string userLogin)
        {
            var ad = await FindAdAsync(adId, isUserAs, userLogin);
            _uow.AdRepo.RemoveEntity(ad);
            await _uow.SaveChangesAsync();
        }

        public async Task CreateAdAsync(CreateAdDto dto, string userLogin)
        {
            var category = await _uow.AdCtgRepo.FindEntityByAsync(x => x.Id.ToString() == dto.CategoryId);
            if (category is null)
                throw new Exception("категория не найдена");

            AdSubCategory subCategory = null;
            if (dto.SubCategoryId is not null)
            {
                subCategory = await _uow.AdSubCtgRepo.FindEntityByAsync(x => x.Id.ToString() == dto.SubCategoryId);
                if (!category.SubCategories.Contains(subCategory))
                    throw new Exception("подкатегории не найдены");
            }

            var ad = new Ad
            {
                AdType = await _uow.AdTypeRepo.FindEntityByAsync(x => x.Id.ToString() == dto.AdTypeId),
                Category = category,
                SubCategory = subCategory,
                User = await _uow.UserRepo.FindEntityByAsync(x => x.Login == userLogin),
                Name = dto.Name,
                Description = dto.Description,
            };

            var result = ad.AdType == null ||
                ad.Category == null ||
                ad.User == null;
            if (result)
                throw new Exception("неверные данный для создания объявления");

            _uow.AdRepo.AddEntity(ad);
            await _uow.SaveChangesAsync();
        }

        private async Task<Ad> FindAdAsync(string adId, bool isUserAd, string userLogin)
        {
            var ad = new Ad();
            if (isUserAd)
            {
                ad = await _uow.AdRepo.FindEntityByIdAsync(adId);
                if (ad is null)
                    throw new Exception("объявление не найдено");
            }
            else
            {
                ad = await _uow.AdRepo.FindEntityByAsync(x => x.Id.ToString() == adId && x.User.Login == userLogin);
                if (ad is null)
                    throw new Exception("объявление не найдено");
            }

            return ad;
        }
    }
}
