﻿using Domain.VolgaIt.Entities;
using Microsoft.EntityFrameworkCore;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Infrastructure.VolgaIt.Context
{
    public class VolgaContext : DbContext
    {
        public VolgaContext(DbContextOptions<VolgaContext> opt) : base(opt)
        {
        }

        public DbSet<User> Users { get; set; }
        public DbSet<AdType> AdTypes { get; set; }
        public DbSet<Ad> UserAds { get; set; }
        public DbSet<AdCategory> AdCategories { get; set; }
        public DbSet<AdSubCategory> AdSubCategories { get; set; }
        public DbSet<UserRole> UserRoles { get; set; }

        protected override void OnModelCreating(ModelBuilder builder)
        {
            var adminRole = new UserRole { Name = "admin", Id = Guid.NewGuid() };
            builder.Entity<UserRole>().HasData(adminRole,
                new UserRole { Name = "moderator", Id = Guid.NewGuid()},
                new UserRole { Name = "user", Id = Guid.NewGuid()});

            var adCategoryAuto = Guid.NewGuid();
            var adCategoryAppliances = Guid.NewGuid();
            var adCategoryRealEstate = Guid.NewGuid();
            builder.Entity<AdCategory>().HasData(new AdCategory { Id = adCategoryAuto, Name = "auto" },
                new AdCategory { Id = adCategoryAppliances, Name = "appliances" },
                new AdCategory { Id = adCategoryRealEstate, Name = "real estate" });

            builder.Entity<AdSubCategory>().HasData(new AdSubCategory { Id = Guid.NewGuid(), Name = "home", AdCategoryId = adCategoryRealEstate },
                new AdSubCategory { Id = Guid.NewGuid(), Name = "country house", AdCategoryId = adCategoryRealEstate },
                new AdSubCategory { Id = Guid.NewGuid(), Name = "foreign car", AdCategoryId = adCategoryAuto },
                new AdSubCategory { Id = Guid.NewGuid(), Name = "domestic car", AdCategoryId = adCategoryAuto });

            builder.Entity<AdType>().HasData(new AdType { Id = Guid.NewGuid(), Name = "buy"},
                new AdType { Id = Guid.NewGuid(), Name = "sell" },
                new AdType { Id = Guid.NewGuid(), Name = "change"},
                new AdType { Id = Guid.NewGuid(), Name = "found" },
                new AdType { Id = Guid.NewGuid(), Name = "loss" },
                new AdType { Id = Guid.NewGuid(), Name = "rent" });

            builder.Entity<User>().HasData(new User { Id = Guid.NewGuid(), Login = "admin", Password = "admin", RoleId = adminRole.Id });
        }

    }
}
