﻿using System;
using Microsoft.EntityFrameworkCore.Migrations;

namespace Infrastructure.VolgaIt.Migrations
{
    public partial class Init : Migration
    {
        protected override void Up(MigrationBuilder migrationBuilder)
        {
            migrationBuilder.CreateTable(
                name: "AdCategories",
                columns: table => new
                {
                    Id = table.Column<Guid>(type: "uuid", nullable: false),
                    Name = table.Column<string>(type: "text", nullable: false)
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_AdCategories", x => x.Id);
                });

            migrationBuilder.CreateTable(
                name: "AdTypes",
                columns: table => new
                {
                    Id = table.Column<Guid>(type: "uuid", nullable: false),
                    Name = table.Column<string>(type: "text", nullable: true)
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_AdTypes", x => x.Id);
                });

            migrationBuilder.CreateTable(
                name: "UserRoles",
                columns: table => new
                {
                    Id = table.Column<Guid>(type: "uuid", nullable: false),
                    Name = table.Column<string>(type: "text", nullable: false)
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_UserRoles", x => x.Id);
                });

            migrationBuilder.CreateTable(
                name: "AdSubCategories",
                columns: table => new
                {
                    Id = table.Column<Guid>(type: "uuid", nullable: false),
                    Name = table.Column<string>(type: "text", nullable: false),
                    AdCategoryId = table.Column<Guid>(type: "uuid", nullable: false)
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_AdSubCategories", x => x.Id);
                    table.ForeignKey(
                        name: "FK_AdSubCategories_AdCategories_AdCategoryId",
                        column: x => x.AdCategoryId,
                        principalTable: "AdCategories",
                        principalColumn: "Id",
                        onDelete: ReferentialAction.Cascade);
                });

            migrationBuilder.CreateTable(
                name: "Users",
                columns: table => new
                {
                    Id = table.Column<Guid>(type: "uuid", nullable: false),
                    Login = table.Column<string>(type: "text", nullable: false),
                    Password = table.Column<string>(type: "text", nullable: false),
                    RoleId = table.Column<Guid>(type: "uuid", nullable: false)
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_Users", x => x.Id);
                    table.ForeignKey(
                        name: "FK_Users_UserRoles_RoleId",
                        column: x => x.RoleId,
                        principalTable: "UserRoles",
                        principalColumn: "Id",
                        onDelete: ReferentialAction.Cascade);
                });

            migrationBuilder.CreateTable(
                name: "UserAds",
                columns: table => new
                {
                    Id = table.Column<Guid>(type: "uuid", nullable: false),
                    Name = table.Column<string>(type: "text", nullable: false),
                    Description = table.Column<string>(type: "text", nullable: true),
                    UserId = table.Column<Guid>(type: "uuid", nullable: false),
                    CategoryId = table.Column<Guid>(type: "uuid", nullable: true),
                    SubCategoryId = table.Column<Guid>(type: "uuid", nullable: true),
                    AdTypeId = table.Column<Guid>(type: "uuid", nullable: true)
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_UserAds", x => x.Id);
                    table.ForeignKey(
                        name: "FK_UserAds_AdCategories_CategoryId",
                        column: x => x.CategoryId,
                        principalTable: "AdCategories",
                        principalColumn: "Id",
                        onDelete: ReferentialAction.Restrict);
                    table.ForeignKey(
                        name: "FK_UserAds_AdSubCategories_SubCategoryId",
                        column: x => x.SubCategoryId,
                        principalTable: "AdSubCategories",
                        principalColumn: "Id",
                        onDelete: ReferentialAction.Restrict);
                    table.ForeignKey(
                        name: "FK_UserAds_AdTypes_AdTypeId",
                        column: x => x.AdTypeId,
                        principalTable: "AdTypes",
                        principalColumn: "Id",
                        onDelete: ReferentialAction.Restrict);
                    table.ForeignKey(
                        name: "FK_UserAds_Users_UserId",
                        column: x => x.UserId,
                        principalTable: "Users",
                        principalColumn: "Id",
                        onDelete: ReferentialAction.Cascade);
                });

            migrationBuilder.InsertData(
                table: "AdCategories",
                columns: new[] { "Id", "Name" },
                values: new object[,]
                {
                    { new Guid("9f1024ae-0b25-46ce-bb6f-eaf3735cf809"), "auto" },
                    { new Guid("e2cb03f7-d060-4d71-b3a0-eb024c8b6524"), "appliances" },
                    { new Guid("d1c14388-3c76-49ac-a2b6-5842f0eeb68c"), "real estate" }
                });

            migrationBuilder.InsertData(
                table: "AdTypes",
                columns: new[] { "Id", "Name" },
                values: new object[,]
                {
                    { new Guid("b57ae60e-6b60-4d4b-a62c-a294b7315629"), "buy" },
                    { new Guid("ad79c460-0262-4b2c-ba1d-6c1d693d4f8c"), "sell" },
                    { new Guid("35121ac9-615e-490e-b566-c06d14eca536"), "change" },
                    { new Guid("912ef4d6-a12b-478a-8738-cf690c863090"), "found" },
                    { new Guid("45136845-20e0-48d8-8a19-cbfb3ea7af27"), "loss" },
                    { new Guid("71b21aa7-beb5-44b7-bbfb-8224950320b2"), "rent" }
                });

            migrationBuilder.InsertData(
                table: "UserRoles",
                columns: new[] { "Id", "Name" },
                values: new object[,]
                {
                    { new Guid("ba6aec9e-db98-4729-88ba-c106574d76d5"), "admin" },
                    { new Guid("99d62217-4d1b-4937-bf42-d8caab3326ad"), "moderator" },
                    { new Guid("9548ad3e-ae93-44bd-8473-522c934d4ca7"), "user" }
                });

            migrationBuilder.InsertData(
                table: "AdSubCategories",
                columns: new[] { "Id", "AdCategoryId", "Name" },
                values: new object[,]
                {
                    { new Guid("369da8d9-1706-4d90-9289-59b2530e2039"), new Guid("9f1024ae-0b25-46ce-bb6f-eaf3735cf809"), "foreign car" },
                    { new Guid("e8c5ccab-3d40-4e70-8e76-23e61ed58c6b"), new Guid("9f1024ae-0b25-46ce-bb6f-eaf3735cf809"), "domestic car" },
                    { new Guid("e63c7665-58c4-4257-ae05-c3cd307edb8f"), new Guid("d1c14388-3c76-49ac-a2b6-5842f0eeb68c"), "home" },
                    { new Guid("570d35b9-660a-4821-bc1b-39c00a3164ba"), new Guid("d1c14388-3c76-49ac-a2b6-5842f0eeb68c"), "country house" }
                });

            migrationBuilder.InsertData(
                table: "Users",
                columns: new[] { "Id", "Login", "Password", "RoleId" },
                values: new object[] { new Guid("947f66f5-71ab-43f0-89fe-a5270c631831"), "admin", "admin", new Guid("ba6aec9e-db98-4729-88ba-c106574d76d5") });

            migrationBuilder.CreateIndex(
                name: "IX_AdSubCategories_AdCategoryId",
                table: "AdSubCategories",
                column: "AdCategoryId");

            migrationBuilder.CreateIndex(
                name: "IX_UserAds_AdTypeId",
                table: "UserAds",
                column: "AdTypeId");

            migrationBuilder.CreateIndex(
                name: "IX_UserAds_CategoryId",
                table: "UserAds",
                column: "CategoryId");

            migrationBuilder.CreateIndex(
                name: "IX_UserAds_SubCategoryId",
                table: "UserAds",
                column: "SubCategoryId");

            migrationBuilder.CreateIndex(
                name: "IX_UserAds_UserId",
                table: "UserAds",
                column: "UserId");

            migrationBuilder.CreateIndex(
                name: "IX_Users_RoleId",
                table: "Users",
                column: "RoleId");
        }

        protected override void Down(MigrationBuilder migrationBuilder)
        {
            migrationBuilder.DropTable(
                name: "UserAds");

            migrationBuilder.DropTable(
                name: "AdSubCategories");

            migrationBuilder.DropTable(
                name: "AdTypes");

            migrationBuilder.DropTable(
                name: "Users");

            migrationBuilder.DropTable(
                name: "AdCategories");

            migrationBuilder.DropTable(
                name: "UserRoles");
        }
    }
}
