﻿using Domain.VolgaIt.Interfaces;
using Infrastructure.VolgaIt.Context;
using Microsoft.EntityFrameworkCore;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Linq.Expressions;
using System.Text;
using System.Threading.Tasks;

namespace Infrastructure.VolgaIt.Repositories
{
    public class BaseRepository<TEntity> : IRepository<TEntity> where TEntity : class
    {
        private VolgaContext _context;

        public BaseRepository(VolgaContext context)
        {
            _context = context;
        }

        public virtual void AddEntity(TEntity entity)
        {
            _context.Set<TEntity>().Add(entity);
        }

        public virtual async Task<List<TEntity>> FindEntitiesByAsync(Expression<Func<TEntity, bool>> filter)
        {
            return await _context.Set<TEntity>().Where(filter).ToListAsync();
        }

        public virtual async Task<TEntity> FindEntityByAsync(Expression<Func<TEntity, bool>> filter)
        {
            return await _context.Set<TEntity>().FirstOrDefaultAsync(filter);
        }

        public virtual async Task<TEntity> FindEntityByIdAsync(string entityId)
        {
            return await _context.Set<TEntity>().FindAsync(Guid.Parse(entityId));
        }

        public virtual async Task<List<TEntity>> GetAllEntitiesAsync()
        {
            return await _context.Set<TEntity>().ToListAsync();
        }

        public virtual void RemoveEntity(TEntity entity)
        {
            _context.Set<TEntity>().Remove(entity);
        }

        public void UpdateEntity(TEntity entity)
        {
            _context.Set<TEntity>().Update(entity);
        }
    }
}
