﻿using App.VolgaIt.Dto;
using App.VolgaIt.Services;
using Microsoft.AspNetCore.Authentication.JwtBearer;
using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Mvc;
using System.Threading.Tasks;

namespace Web.VolgaIt.Controllers
{
   [ApiController]
   [Route("api/[controller]")]
    public class AccountController : Controller
    {
        public readonly AccountService _accountService;

        public AccountController(AccountService accountService)
        {
            _accountService = accountService;
        }

        [HttpPost("register/user")]
        [AllowAnonymous]
        public async Task RegisterUserAsync(RegisterDto dto)
        {
            await _accountService.RegisterUserAsync(dto);
        }

        [HttpPost("sign-in")]
        [AllowAnonymous]
        public async Task<string> SignInAsync(SignInDto dto)
        {
            return await _accountService.SignInAsync(dto);
        }

        [HttpPost("register/admin")]
        [Authorize(AuthenticationSchemes = JwtBearerDefaults.AuthenticationScheme, Roles = "admin")]
        public async Task RegisterAdmin(RegisterDto dto)
        {
            await _accountService.RegisterAdminAsync(dto);
        }

        [HttpPost("register/moderator")]
        [Authorize(AuthenticationSchemes = JwtBearerDefaults.AuthenticationScheme, Roles = "admin")]
        public async Task RegisterModerator(RegisterDto dto)
        {
            await _accountService.RegisterModeratorAsync(dto);
        }
    }
}
