﻿using App.VolgaIt.Dto;
using App.VolgaIt.Services;
using Domain.VolgaIt.Entities;
using Microsoft.AspNetCore.Authentication.JwtBearer;
using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Mvc;
using System.Collections.Generic;
using System.IdentityModel.Tokens.Jwt;
using System.Linq;
using System.Net.Http.Headers;
using System.Security.Claims;
using System.Threading.Tasks;
using Web.VolgaIt.Helpers;

namespace Web.VolgaIt.Controllers
{
    [Route("api/[controller]")]
    [ApiController]
    [Authorize(AuthenticationSchemes = JwtBearerDefaults.AuthenticationScheme)]
    public class AdController : Controller
    {
        private readonly AdService _adService;

        public AdController(AdService adService)
        {
            _adService = adService;
        }

        [HttpGet("ads")]
        [AllowAnonymous]
        public async Task<List<AdDto>> GetAllAds()
        {
            return await _adService.GetAllAdsAsync();
        }

        [HttpGet("ads/category/{categoryName}")]
        [AllowAnonymous]
        public async Task<List<AdDto>> GetAdsByCategoryName(string categoryName)
        {
            return await _adService.GetAdsByCategoryNameAsync(categoryName);
        }

        [HttpGet("ads/sub-category/{subCategoryName}")]
        [AllowAnonymous]
        public async Task<List<AdDto>> GetAdsBySubCategoryName(string subCategoryName)
        {
            return await _adService.GetAdsBySubCategoryNameAsync(subCategoryName);
        }


        [HttpPost("ads/ad")]
        public async Task CreateAdAsync(CreateAdDto dto)
        {
            await _adService.CreateAdAsync(dto, HttpContext.GetLoginHttpUser());
        }
    }
}
