﻿using App.VolgaIt.Dto;
using App.VolgaIt.Services;
using Microsoft.AspNetCore.Authentication.JwtBearer;
using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Mvc;
using System.Threading.Tasks;
using Web.VolgaIt.Helpers;

namespace Web.VolgaIt.Controllers
{
    [ApiController]
    [Route("api/control")]
    [Authorize(AuthenticationSchemes = JwtBearerDefaults.AuthenticationScheme)]
    public class ManagersController : Controller
    {
        private readonly AdService _adService;
        private readonly UserService _userService;

        public ManagersController(AdService adService, UserService userService)
        {
            _adService = adService;
            _userService = userService;
        }

        [HttpPut("ads/ad")]
        [Authorize(Roles = "admin,moderator")]
        public async Task EditAdAsync(EditAdDto dto)
        {
            await _adService.EditAdAsync(dto, false, HttpContext.GetLoginHttpUser());
        }

        [HttpDelete("ads/ad/{adId}")]
        [Authorize(Roles = "admin")]
        public async Task RemoveAdAsync(string adId)
        {
            await _adService.RemoveAdAsync(adId, false, HttpContext.GetLoginHttpUser()); ;
        }


        [HttpPut("edit/name")]
        [Authorize(Roles = "admin,moderator")]
        public async Task EditNameAsync(EditNameDto dto)
        {
            await _userService.EditUserNameAsync(dto);
        }
    }
}
