﻿using App.VolgaIt.Dto;
using App.VolgaIt.Services;
using Microsoft.AspNetCore.Authentication.JwtBearer;
using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Mvc;
using System.Threading.Tasks;
using Web.VolgaIt.Helpers;


namespace Web.VolgaIt.Controllers
{
    [ApiController]
    [Route("api/my")]
    [Authorize(AuthenticationSchemes = JwtBearerDefaults.AuthenticationScheme, Roles = "user")]
    public class PersonalAreaController : Controller
    {
        private readonly AdService _adService;
        private readonly UserService _userService;

        public PersonalAreaController(UserService userService, AdService adService)
        {
            _adService = adService;
            _userService = userService;
        }

        [HttpPut("edit/name")]
        public async Task EditUserNameAsync(string newName)
        {
            var editNameDto = new EditNameDto
            {
                OldName = HttpContext.GetLoginHttpUser(),
                NewName = newName
            };
            await _userService.EditUserNameAsync(editNameDto);
        }

        [HttpPut("ad")]
        public async Task EditAdAsync(EditAdDto dto)
        {
            await _adService.EditAdAsync(dto, true, HttpContext.GetLoginHttpUser());
        }


        [HttpDelete("ad/{adId}")]
        public async Task RemoveAdAsync(string adId)
        {
            await _adService.RemoveAdAsync(adId, true, HttpContext.GetLoginHttpUser());
        }
    }
}
